@@ -6,20 +6,21 @@
 #include <iostream>
 
 CClickFilter::CClickFilter(Dasher::CEventHandler * pEventHandler, CSettingsStore *pSettingsStore, CDasherInterfaceBase *pInterface)
-  : CInputFilter(pEventHandler, pSettingsStore, pInterface) {
+  : CInputFilter(pEventHandler, pSettingsStore, pInterface, 7, 1, "Click Mode") {
   pDasherView = 0;
 }
 
 CClickFilter::~CClickFilter() {
 }
 
-void CClickFilter::DecorateView(CDasherView *pView) {
+bool CClickFilter::DecorateView(CDasherView *pView) {
+  return false;
 }
 
-void CClickFilter::Timer(int Time, CDasherView *m_pDasherView, CDasherModel *m_pDasherModel) {
+bool CClickFilter::Timer(int Time, CDasherView *m_pDasherView, CDasherModel *m_pDasherModel) {
   // FIXME - REALLY, REALLY horrible - bleh
-  m_pDasherModel->Tap_on_display(0, 0, Time, 0, 0);
   pDasherView = m_pDasherView;
+  return m_pDasherModel->Tap_on_display(0, 0, Time, 0, 0);
 }
 
 void CClickFilter::KeyDown(int iTime, int iId, CDasherModel *pModel) {
